You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [3/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sour...

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -125,7 +125,7 @@ static void callVirtualMethod(
 
 #if 0
      /* Let's figure out what is really going on here*/
-     fprintf(stderr,"callVirtualMethod paramters string is %s\n",pPT);
+     fprintf(stderr,"callVirtualMethod parameters string is %s\n",pPT);
      int k = nStackLongs;
      long * q = (long *)pStackLongs;
      while (k > 0) {
@@ -483,7 +483,7 @@ static void cpp_call(
 			pAdjustedThisPtr, aVtableSlot.index,
 			pCppReturn, pReturnTypeDescr->eTypeClass, pParamType,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -410,7 +410,7 @@ static void cpp_call(
                         pStackStart, ( pStack - pStackStart ),
                         pGPR, nGPR,
                         pFPR, nFPR );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -439,7 +439,7 @@ static void cpp_call(
 			pAdjustedThisPtr, aVtableSlot.index,
 			pCppReturn, pReturnTypeDescr->eTypeClass, pParamType,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -342,7 +342,7 @@ static void cpp_call(
             pStackStart, (pStack - pStackStart),
             pGPR, nGPR,
             pFPR, nFPR );
-        // NO exception occured...
+        // NO exception occurred...
         *ppUnoExc = 0;
         
         // reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/except.cxx Tue Apr 29 19:05:05 2014
@@ -223,7 +223,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -297,7 +297,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if defined BRIDGES_DEBUG
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -408,7 +408,7 @@ static void cpp_call(
 			pReturnTypeDescr->eTypeClass,
 			(sal_Int32 *)pCppStackStart,
 			 nStackLongs);
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/except.cxx Tue Apr 29 19:05:05 2014
@@ -225,7 +225,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -299,7 +299,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if OSL_DEBUG_LEVEL > 1
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -408,7 +408,7 @@ static void cpp_call(
                 Reference< XInterface >());
         }
 
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/except.cxx Tue Apr 29 19:05:05 2014
@@ -224,7 +224,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -298,7 +298,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if OSL_DEBUG_LEVEL > 1
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -283,7 +283,7 @@ static void cpp_call(
 			pAdjustedThisPtr, aVtableSlot.index,
 			pCppReturn, pReturnTypeDescr, bSimpleReturn,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -445,7 +445,7 @@ static void cpp_call(
 			pAdjustedThisPtr, aVtableSlot.index,
 			pCppReturn, pReturnTypeDescr->eTypeClass, pParamType,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/except.cxx Tue Apr 29 19:05:05 2014
@@ -226,7 +226,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -300,7 +300,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if defined DEBUG
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -246,7 +246,7 @@ static void cpp_call(
 			pThis->pCppI, nVtableCall,
 			pCppReturn, pReturnTypeDescr->eTypeClass,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/except.cxx Tue Apr 29 19:05:05 2014
@@ -233,7 +233,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -307,7 +307,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if OSL_DEBUG_LEVEL > 1
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -265,7 +265,7 @@ static void cpp_call(
 			pAdjustedThisPtr, aVtableSlot.index,
 			pCppReturn, pReturnTypeDescr->eTypeClass,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/except.cxx Tue Apr 29 19:05:05 2014
@@ -224,7 +224,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -298,7 +298,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if OSL_DEBUG_LEVEL > 1
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -256,7 +256,7 @@ static void cpp_call(
 			pAdjustedThisPtr, aVtableSlot.index,
 			pCppReturn, pReturnTypeDescr->eTypeClass,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/except.cxx Tue Apr 29 19:05:05 2014
@@ -222,7 +222,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -296,7 +296,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if defined BRIDGES_DEBUG
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -403,7 +403,7 @@ static void cpp_call(
 			pReturnTypeDescr->eTypeClass,
 			(sal_Int32 *)pCppStackStart,
 			 nStackLongs);
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/except.cxx Tue Apr 29 19:05:05 2014
@@ -209,7 +209,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -283,7 +283,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if OSL_DEBUG_LEVEL > 1
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -300,7 +300,7 @@ static void cpp_call(
 			pAdjustedThisPtr, aVtableSlot.index,
 			pCppReturn, pReturnTypeDescr,
 			(sal_Int32 *)pCppStackStart, (pCppStack - pCppStackStart) / sizeof(sal_Int32) );
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx Tue Apr 29 19:05:05 2014
@@ -614,7 +614,7 @@ int msci_filterCppException(
     RuntimeException exc(
         OUString( RTL_CONSTASCII_USTRINGPARAM(
                       "[msci_uno bridge error] unexpected "
-                      "C++ exception occured!") ),
+                      "C++ exception occurred!") ),
         Reference< XInterface >() );
     uno_type_any_constructAndConvert(
         pUnoExc, &exc, ::getCppuType( &exc ).getTypeLibType(), pCpp2Uno );

Modified: openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -286,7 +286,7 @@ static void cpp_call(
         return;
 	}
     
-    // NO exception occured
+    // NO exception occurred
     *ppUnoExc = 0;
     
     // reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/cpp2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/cpp2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/except.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/except.cxx Tue Apr 29 19:05:05 2014
@@ -242,7 +242,7 @@ void raiseException( uno_Any * pUnoExc, 
         OUStringToOString(
             *reinterpret_cast< OUString const * >( &pUnoExc->pType->pTypeName ),
             RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> uno exception occured: %s\n", cstr.getStr() );
+    fprintf( stderr, "> uno exception occurred: %s\n", cstr.getStr() );
 #endif
     void * pCppExc;
     type_info * rtti;
@@ -316,7 +316,7 @@ void fillUnoException( __cxa_exception *
     OUString unoName( toUNOname( header->exceptionType->name() ) );
 #if OSL_DEBUG_LEVEL > 1
     OString cstr_unoName( OUStringToOString( unoName, RTL_TEXTENCODING_ASCII_US ) );
-    fprintf( stderr, "> c++ exception occured: %s\n", cstr_unoName.getStr() );
+    fprintf( stderr, "> c++ exception occurred: %s\n", cstr_unoName.getStr() );
 #endif
 	typelib_typedescription_getByName( &pExcTypeDescr, unoName.pData );
     if (0 == pExcTypeDescr)

Modified: openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/uno2cpp.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/uno2cpp.cxx Tue Apr 29 19:05:05 2014
@@ -409,7 +409,7 @@ static void cpp_call(
                 Reference< XInterface >());
         }
 
-		// NO exception occured...
+		// NO exception occurred...
 		*ppUnoExc = 0;
 		
 		// reconvert temporary params

Modified: openoffice/trunk/main/bridges/source/cpp_uno/shared/component.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/shared/component.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/shared/component.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/shared/component.cxx Tue Apr 29 19:05:05 2014
@@ -144,7 +144,7 @@ static void s_stub_computeObjectIdentifi
         catch (::com::sun::star::uno::RuntimeException &)
         {
             OSL_ENSURE(
-                0, "### RuntimeException occured udring queryInterface()!" );
+                0, "### RuntimeException occurred udring queryInterface()!" );
         }
     }
 }

Modified: openoffice/trunk/main/bridges/source/jni_uno/jni_base.h
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/jni_uno/jni_base.h?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/jni_uno/jni_base.h (original)
+++ openoffice/trunk/main/bridges/source/jni_uno/jni_base.h Tue Apr 29 19:05:05 2014
@@ -122,7 +122,7 @@ inline bool JNI_context::assert_no_excep
     if (JNI_FALSE != m_env->ExceptionCheck())
     {
         m_env->ExceptionClear();
-        OSL_ENSURE( 0, "unexpected java exception occured!" );
+        OSL_ENSURE( 0, "unexpected java exception occurred!" );
         return false;
     }
     return true;

Modified: openoffice/trunk/main/bridges/source/jni_uno/jni_bridge.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/jni_uno/jni_bridge.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/jni_uno/jni_bridge.cxx (original)
+++ openoffice/trunk/main/bridges/source/jni_uno/jni_bridge.cxx Tue Apr 29 19:05:05 2014
@@ -297,7 +297,7 @@ void JNI_context::java_exc_occured() con
     if (! jo_exc.is())
     {
         throw BridgeRuntimeError(
-            OUSTR("java exception occured, but not available!?") +
+            OUSTR("java exception occurred, but not available!?") +
             get_stack_trace() );
     }
 

Modified: openoffice/trunk/main/bridges/source/jni_uno/jni_java2uno.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/jni_uno/jni_java2uno.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/jni_uno/jni_java2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/jni_uno/jni_java2uno.cxx Tue Apr 29 19:05:05 2014
@@ -105,7 +105,7 @@ void Bridge::handle_uno_exc( JNI_context
         {
         OUStringBuffer buf( 128 );
         buf.appendAscii(
-            RTL_CONSTASCII_STRINGPARAM("exception occured java->uno: [") );
+            RTL_CONSTASCII_STRINGPARAM("exception occurred java->uno: [") );
         buf.append( OUString::unacquired( &uno_exc->pType->pTypeName ) );
         buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("] ") );
         buf.append(
@@ -356,7 +356,7 @@ jobject Bridge::call_uno(
 #endif
         return 0; // void return
     }
-    else // exception occured
+    else // exception occurred
     {
         // destruct uno in args
         for ( sal_Int32 nPos = 0; nPos < nParams; ++nPos )

Modified: openoffice/trunk/main/bridges/source/jni_uno/jni_uno2java.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/jni_uno/jni_uno2java.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/bitmapcanvasbase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/bitmapcanvasbase.hxx Tue Apr 29 19:05:05 2014
@@ -48,7 +48,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/bufferedgraphicdevicebase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/bufferedgraphicdevicebase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/bufferedgraphicdevicebase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/bufferedgraphicdevicebase.hxx Tue Apr 29 19:05:05 2014
@@ -73,7 +73,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/canvasbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/canvasbase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/canvasbase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/canvasbase.hxx Tue Apr 29 19:05:05 2014
@@ -78,13 +78,13 @@ namespace canvas
         Canvas helper implementation for the backend in question. This
         object will be held as a member of this template class, and
         basically gets forwarded all XCanvas API calls. Furthermore,
-        everytime the canvas API semantically changes the content of
+        every time the canvas API semantically changes the content of
         the canvas, CanvasHelper::modifying() will get called
         (<em>before</em> the actual modification takes place).
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/canvascustomspritebase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/canvascustomspritebase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/canvascustomspritebase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/canvascustomspritebase.hxx Tue Apr 29 19:05:05 2014
@@ -60,7 +60,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/doublebitmapbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/doublebitmapbase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/doublebitmapbase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/doublebitmapbase.hxx Tue Apr 29 19:05:05 2014
@@ -49,7 +49,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/floatbitmapbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/floatbitmapbase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/floatbitmapbase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/floatbitmapbase.hxx Tue Apr 29 19:05:05 2014
@@ -49,7 +49,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/graphicdevicebase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/graphicdevicebase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/graphicdevicebase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/graphicdevicebase.hxx Tue Apr 29 19:05:05 2014
@@ -90,7 +90,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        BaseMutexHelper-provided lock.  Everytime one of the methods is
+        BaseMutexHelper-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/integerbitmapbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/integerbitmapbase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/integerbitmapbase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/integerbitmapbase.hxx Tue Apr 29 19:05:05 2014
@@ -49,7 +49,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/base/spritecanvasbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/spritecanvasbase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/base/spritecanvasbase.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/base/spritecanvasbase.hxx Tue Apr 29 19:05:05 2014
@@ -52,7 +52,7 @@ namespace canvas
 
         @tpl Mutex
         Lock strategy to use. Defaults to using the
-        OBaseMutex-provided lock.  Everytime one of the methods is
+        OBaseMutex-provided lock.  Every time one of the methods is
         entered, an object of type Mutex is created with m_aMutex as
         the sole parameter, and destroyed again when the method scope
         is left.

Modified: openoffice/trunk/main/canvas/inc/canvas/canvastools.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/canvastools.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/canvastools.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/canvastools.hxx Tue Apr 29 19:05:05 2014
@@ -454,7 +454,7 @@ namespace canvas
         /// Convert standard 8888 RGBA color to vcl color
         ::com::sun::star::uno::Sequence<sal_Int8> colorToStdIntSequence( const ::Color& rColor );
 
-        // Modeled closely after boost::numeric_cast, only that we
+        // Modelled closely after boost::numeric_cast, only that we
         // issue some trace output here and throw a RuntimeException
 
         /** Cast numeric value into another (numeric) data type
@@ -470,7 +470,7 @@ namespace canvas
             typedef ::std::numeric_limits< Source > SourceLimits;
             typedef ::std::numeric_limits< Target > TargetLimits;
 
-            if( ( arg<0 && !TargetLimits::is_signed) || 					// loosing the sign here
+            if( ( arg<0 && !TargetLimits::is_signed) || 					// losing the sign here
                 ( SourceLimits::is_signed && arg<TargetLimits::min()) ||	// underflow will happen
                 ( arg>TargetLimits::max() ) ) 					            // overflow will happen
             {

Modified: openoffice/trunk/main/canvas/inc/canvas/rendering/irendermodule.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/rendering/irendermodule.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/inc/canvas/rendering/irendermodule.hxx (original)
+++ openoffice/trunk/main/canvas/inc/canvas/rendering/irendermodule.hxx Tue Apr 29 19:05:05 2014
@@ -114,7 +114,7 @@ namespace canvas
 
         /** Query error status
 
-            @returns true, if an error occured during primitive
+            @returns true, if an error occurred during primitive
             construction.
          */
 		virtual bool      isError() = 0;

Modified: openoffice/trunk/main/canvas/source/cairo/cairo_canvasbitmap.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/cairo/cairo_canvasbitmap.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/cairo/cairo_canvasbitmap.cxx (original)
+++ openoffice/trunk/main/canvas/source/cairo/cairo_canvasbitmap.cxx Tue Apr 29 19:05:05 2014
@@ -49,7 +49,7 @@ namespace
 {
     HBITMAP surface2HBitmap( const SurfaceSharedPtr& rSurface, const basegfx::B2ISize& rSize )
     {
-        // cant seem to retrieve HBITMAP from cairo. copy content then
+        // can't seem to retrieve HBITMAP from cairo. copy content then
         HDC hScreenDC=GetDC(NULL);
         HBITMAP hBmpBitmap = CreateCompatibleBitmap( hScreenDC, 
                                                      rSize.getX(), 
@@ -242,7 +242,7 @@ namespace cairocanvas
                 cairo_paint( pAlphaCairo.get() );
                 pAlphaCairo.reset();
 
-                // cant seem to retrieve HBITMAP from cairo. copy content then
+                // can't seem to retrieve HBITMAP from cairo. copy content then
                 uno::Sequence< uno::Any > args( 1 );
                 args[1] = uno::Any( sal_Int64(surface2HBitmap(pAlphaSurface,maSize)) );
                 

Modified: openoffice/trunk/main/canvas/source/cairo/cairo_canvasfont.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/cairo/cairo_canvasfont.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/cairo/cairo_canvasfont.cxx (original)
+++ openoffice/trunk/main/canvas/source/cairo/cairo_canvasfont.cxx Tue Apr 29 19:05:05 2014
@@ -87,7 +87,7 @@ namespace cairocanvas
 
         maFont->SetLanguage(MsLangId::convertLocaleToLanguage(rFontRequest.Locale));
 
-        // adjust to stretched/shrinked font
+        // adjust to stretched/shrunk font
         if( !::rtl::math::approxEqual( rFontMatrix.m00, rFontMatrix.m11) )
         {
             OutputDevice* pOutDev( mpRefDevice->getOutputDevice() );

Modified: openoffice/trunk/main/canvas/source/cairo/cairo_canvashelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/cairo/cairo_canvashelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/cairo/cairo_canvashelper.cxx (original)
+++ openoffice/trunk/main/canvas/source/cairo/cairo_canvashelper.cxx Tue Apr 29 19:05:05 2014
@@ -598,7 +598,7 @@ namespace cairocanvas
 							aColor = pBitmapReadAcc->GetColor( nY, nX );
 
 							// cairo need premultiplied color values
-							// TODO(rodo) handle endianess
+							// TODO(rodo) handle endianness
 #ifdef OSL_BIGENDIAN
 							if( pAlphaReadAcc )
 								nAlpha = data[ nOff++ ];

Modified: openoffice/trunk/main/canvas/source/cairo/cairo_quartz_cairo.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/cairo/cairo_quartz_cairo.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/cairo/cairo_quartz_cairo.cxx (original)
+++ openoffice/trunk/main/canvas/source/cairo/cairo_quartz_cairo.cxx Tue Apr 29 19:05:05 2014
@@ -310,7 +310,7 @@ namespace cairo
     }
 
     /**
-     * cairo::createBitmapSurface:   Create platfrom native Canvas surface from BitmapSystemData
+     * cairo::createBitmapSurface:   Create platform native Canvas surface from BitmapSystemData
      * @param OutputDevice (not used)
      * @param rData Platform native image data (struct BitmapSystemData in vcl/inc/bitmap.hxx)
      * @param rSize width and height of the new surface

Modified: openoffice/trunk/main/canvas/source/cairo/cairo_textlayout.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/cairo/cairo_textlayout.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/cairo/cairo_textlayout.cxx (original)
+++ openoffice/trunk/main/canvas/source/cairo/cairo_textlayout.cxx Tue Apr 29 19:05:05 2014
@@ -343,7 +343,7 @@ namespace cairocanvas
   /**
    * TextLayout::isCairoRenderable
    *
-   * Features currenly not supported by Cairo (VCL rendering is used as fallback):
+   * Features currently not supported by Cairo (VCL rendering is used as fallback):
    * - vertical glyphs
    *
    * @return true, if text/font can be rendered with cairo
@@ -547,7 +547,7 @@ namespace cairocanvas
             FontMetric aMetric( rOutDev.GetFontMetric(aFont) );
             long nWidth = 0;
             
-            // width calculation is deep magic and platform/font dependant.
+            // width calculation is deep magic and platform/font dependent.
             // width == 0 means no scaling, and usually width == height means the same.
             // Other values mean horizontal scaling (narrow or stretching)
             // see issue #101566

Modified: openoffice/trunk/main/canvas/source/cairo/cairo_win32_cairo.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/cairo/cairo_win32_cairo.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/cairo/cairo_win32_cairo.cxx (original)
+++ openoffice/trunk/main/canvas/source/cairo/cairo_win32_cairo.cxx Tue Apr 29 19:05:05 2014
@@ -88,7 +88,7 @@ namespace cairo
 	}
 
     /**
-     * Surface::Surface:   Create platfrom native Canvas surface from BitmapSystemData
+     * Surface::Surface:   Create platform native Canvas surface from BitmapSystemData
      * @param pBmpData Platform native image data (struct BitmapSystemData in vcl/inc/bitmap.hxx)
      *
      * Create a surface based on image data on pBmpData
@@ -255,7 +255,7 @@ namespace cairo
 
 
     /**
-     * cairo::createBitmapSurface:   Create platfrom native Canvas surface from BitmapSystemData
+     * cairo::createBitmapSurface:   Create platform native Canvas surface from BitmapSystemData
      * @param OutputDevice (not used)
      * @param rData Platform native image data (struct BitmapSystemData in vcl/inc/bitmap.hxx)
      * @param rSize width and height of the new surface

Modified: openoffice/trunk/main/canvas/source/cairo/cairo_xlib_cairo.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/cairo/cairo_xlib_cairo.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/cairo/cairo_xlib_cairo.cxx (original)
+++ openoffice/trunk/main/canvas/source/cairo/cairo_xlib_cairo.cxx Tue Apr 29 19:05:05 2014
@@ -154,7 +154,7 @@ namespace cairo
     }
 
     /**
-     * Surface::Surface:   Create platfrom native Canvas surface from BitmapSystemData
+     * Surface::Surface:   Create platform native Canvas surface from BitmapSystemData
      * @param pSysData Platform native system environment data (struct SystemEnvData in vcl/inc/sysdata.hxx)
      * @param pBmpData Platform native image data (struct BitmapSystemData in vcl/inc/bitmap.hxx)
      * @param width width of the new surface

Modified: openoffice/trunk/main/canvas/source/directx/dx_vcltools.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/directx/dx_vcltools.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/directx/dx_vcltools.cxx (original)
+++ openoffice/trunk/main/canvas/source/directx/dx_vcltools.cxx Tue Apr 29 19:05:05 2014
@@ -116,7 +116,7 @@ namespace dxcanvas
                     !aBmpSysData.pDIB )
                 {
                     // first of all, ensure that Bitmap contains a DIB, by
-                    // aquiring a read access
+                    // acquiring a read access
                     BitmapReadAccess* pReadAcc = rBmp.AcquireReadAccess();
 
                     // TODO(P2): Acquiring a read access can actually

Modified: openoffice/trunk/main/canvas/source/tools/pagemanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/tools/pagemanager.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/tools/pagemanager.cxx (original)
+++ openoffice/trunk/main/canvas/source/tools/pagemanager.cxx Tue Apr 29 19:05:05 2014
@@ -171,7 +171,7 @@ namespace canvas
 		PageContainer_t::iterator       it(maPages.begin());
 		while(it != aEnd)
 		{
-			// if the page at hand takes the fragment, we immediatelly
+			// if the page at hand takes the fragment, we immediately
 			// call select() to pull the information from the associated
 			// image to the hardware surface.
 			if((*it)->nakedFragment(pFragment))

Modified: openoffice/trunk/main/canvas/source/tools/surface.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/tools/surface.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/tools/surface.hxx (original)
+++ openoffice/trunk/main/canvas/source/tools/surface.hxx Tue Apr 29 19:05:05 2014
@@ -43,7 +43,7 @@ namespace canvas
 	// Surface
 	//////////////////////////////////////////////////////////////////////////////////
 
-	/** surfaces denote occupied areas withing pages.
+	/** surfaces denote occupied areas within pages.
 
 		pages encapsulate the hardware buffers that
 		contain image data which can be used for texturing.

Modified: openoffice/trunk/main/canvas/source/tools/surfaceproxy.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/tools/surfaceproxy.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/tools/surfaceproxy.hxx (original)
+++ openoffice/trunk/main/canvas/source/tools/surfaceproxy.hxx Tue Apr 29 19:05:05 2014
@@ -41,7 +41,7 @@ namespace canvas
 
 	    Surface proxies are the connection between *one* source image
 	    and *one or more* hardware surfaces (or textures).  in a
-	    logical structure surface proxies represent soley this
+	    logical structure surface proxies represent solely this
 	    dependeny plus some simple cache management.
     */
     class SurfaceProxy : public ISurfaceProxy

Modified: openoffice/trunk/main/canvas/source/vcl/canvasfont.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/source/vcl/canvasfont.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/source/vcl/canvasfont.cxx (original)
+++ openoffice/trunk/main/canvas/source/vcl/canvasfont.cxx Tue Apr 29 19:05:05 2014
@@ -67,7 +67,7 @@ namespace vclcanvas
 
 		maFont->SetLanguage(MsLangId::convertLocaleToLanguage(rFontRequest.Locale));
 
-        // adjust to stretched/shrinked font
+        // adjust to stretched/shrunk font
         if( !::rtl::math::approxEqual( rFontMatrix.m00, rFontMatrix.m11) )
         {
             OutputDevice& rOutDev( rOutDevProvider->getOutDev() );

Modified: openoffice/trunk/main/canvas/workben/canvasdemo.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/workben/canvasdemo.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/canvas/workben/canvasdemo.cxx (original)
+++ openoffice/trunk/main/canvas/workben/canvasdemo.cxx Tue Apr 29 19:05:05 2014
@@ -471,7 +471,7 @@ class DemoRenderer
 			//begin hacks
 			//This stuff doesn't belong here, but probably in curves
 			//This stuff doesn't work in VCL b/c vcl doesn't do beziers
-			//Hah!  Everytime the window redraws, we do this
+			//Hah!  Every time the window redraws, we do this
 			double ax;
 			double ay;
 			double bx;

Modified: openoffice/trunk/main/chart2/source/controller/chartapiwrapper/Chart2ModelContact.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/chartapiwrapper/Chart2ModelContact.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/controller/chartapiwrapper/Chart2ModelContact.hxx (original)
+++ openoffice/trunk/main/chart2/source/controller/chartapiwrapper/Chart2ModelContact.hxx Tue Apr 29 19:05:05 2014
@@ -88,7 +88,7 @@ public:
      */
     ::com::sun::star::awt::Size GetPageSize() const;
 
-    /** calculates the current axes title sizes and substract that space them from the given recangle
+    /** calculates the current axes title sizes and subtract that space them from the given recangle
      */
     ::com::sun::star::awt::Rectangle SubstractAxisTitleSizes( const ::com::sun::star::awt::Rectangle& rPositionRect );
 

Modified: openoffice/trunk/main/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx (original)
+++ openoffice/trunk/main/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx Tue Apr 29 19:05:05 2014
@@ -1025,7 +1025,7 @@ void ChartDocumentWrapper::impl_resetAdd
     {
         try
         {
-            //make sure that the add-in does not hold a refernce to us anymore:
+            //make sure that the add-in does not hold a references to us anymore:
             Reference< lang::XComponent > xComp( xAddIn, uno::UNO_QUERY );
             if( xComp.is())
                 xComp->dispose();

Modified: openoffice/trunk/main/chart2/source/controller/dialogs/DataBrowserModel.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/dialogs/DataBrowserModel.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/controller/dialogs/DataBrowserModel.cxx (original)
+++ openoffice/trunk/main/chart2/source/controller/dialogs/DataBrowserModel.cxx Tue Apr 29 19:05:05 2014
@@ -413,7 +413,7 @@ void DataBrowserModel::insertDataSeries(
                 }
                 if( nSeriesNumberFormat != 0 )
                 {
-                    //give the new series the same number format as the former series especially for bubble charts thus the bubble size values can be edited with same format immidiately
+                    //give the new series the same number format as the former series especially for bubble charts thus the bubble size values can be edited with same format immediately
                     Reference< beans::XPropertySet > xNewSeriesProps( xNewSeries, uno::UNO_QUERY );
                     if( xNewSeriesProps.is() )
                         xNewSeriesProps->setPropertyValue( C2U( "NumberFormat" ), uno::makeAny( nSeriesNumberFormat ) );

Modified: openoffice/trunk/main/chart2/source/controller/dialogs/ObjectNameProvider.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/dialogs/ObjectNameProvider.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/controller/dialogs/ObjectNameProvider.cxx (original)
+++ openoffice/trunk/main/chart2/source/controller/dialogs/ObjectNameProvider.cxx Tue Apr 29 19:05:05 2014
@@ -567,7 +567,7 @@ rtl::OUString ObjectNameProvider::getHel
     else if( OBJECTTYPE_DIAGRAM == eObjectType )
     {
         //todo different names for different diagram types ???
-        //or different names for series of diferent charttypes
+        //or different names for series of different charttypes
     }
     */
     else if( OBJECTTYPE_DATA_CURVE == eObjectType )

Modified: openoffice/trunk/main/chart2/source/controller/main/ChartController.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/controller/main/ChartController.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/controller/main/ChartController.cxx (original)
+++ openoffice/trunk/main/chart2/source/controller/main/ChartController.cxx Tue Apr 29 19:05:05 2014
@@ -235,7 +235,7 @@ void ChartController::TheModel::tryTermi
 			}
 			catch( util::CloseVetoException& )
 			{
-				//since we have indicated to give up the ownership with paramter true in close call
+				//since we have indicated to give up the ownership with parameter true in close call
 				//the one who has thrown the CloseVetoException is the new owner
 
 #if OSL_DEBUG_LEVEL > 2

Modified: openoffice/trunk/main/chart2/source/inc/DataSeriesHelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/inc/DataSeriesHelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/inc/DataSeriesHelper.hxx (original)
+++ openoffice/trunk/main/chart2/source/inc/DataSeriesHelper.hxx Tue Apr 29 19:05:05 2014
@@ -102,7 +102,7 @@ OOO_DLLPUBLIC_CHARTTOOLS ::rtl::OUString
         ::com::sun::star::chart2::XDataSeries > & xSeries,
     const ::rtl::OUString & rLabelSequenceRole );
 
-/** Get the label of a labeled sequence including neccessary automatic generation
+/** Get the label of a labeled sequence including necessary automatic generation
  */
 OOO_DLLPUBLIC_CHARTTOOLS ::rtl::OUString getLabelForLabeledDataSequence(
     const ::com::sun::star::uno::Reference<

Modified: openoffice/trunk/main/chart2/source/inc/DiagramHelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/inc/DiagramHelper.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/inc/DiagramHelper.hxx (original)
+++ openoffice/trunk/main/chart2/source/inc/DiagramHelper.hxx Tue Apr 29 19:05:05 2014
@@ -156,7 +156,7 @@ public:
             ::com::sun::star::chart2::XDiagram > & xDiagram,
         sal_Int32 nNewDimensionCount );
 
-    /** Replaces all occurences of xCooSysToReplace in the tree with
+    /** Replaces all occurrences of xCooSysToReplace in the tree with
         xReplacement in the diagram's tree
      */
     SAL_DLLPRIVATE static void replaceCoordinateSystem(

Modified: openoffice/trunk/main/chart2/source/inc/ObjectIdentifier.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/inc/ObjectIdentifier.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/inc/ObjectIdentifier.hxx (original)
+++ openoffice/trunk/main/chart2/source/inc/ObjectIdentifier.hxx Tue Apr 29 19:05:05 2014
@@ -86,7 +86,7 @@ class OOO_DLLPUBLIC_CHARTTOOLS ObjectIde
     //syntax of a CID:  CID:/classification/ObjectID
 
     //where classification: nothing or "MultiClick" or "DragMethod=DragMethodServiceName" and "DragParameter=DragParameterString"
-    //                      or a combination of these seperated with a colon
+    //                      or a combination of these separated with a colon
     //where DragMethodServiceName can be a selfdefined servicename for special actions //todo define standard service for this purpose
     //where DragParameterString is any string you like to transport information to your special drag service
     //                            only semicolon, colon, equal sign and slash are not allowed characters

Modified: openoffice/trunk/main/chart2/source/tools/LifeTime.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/tools/LifeTime.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/tools/LifeTime.cxx (original)
+++ openoffice/trunk/main/chart2/source/tools/LifeTime.cxx Tue Apr 29 19:05:05 2014
@@ -267,7 +267,7 @@ bool CloseableLifeTimeManager::impl_isDi
 	void CloseableLifeTimeManager
 ::g_close_endTryClose(sal_Bool bDeliverOwnership, sal_Bool /* bMyVeto */ )
 {
-	//this method is called, if the try to close was not successfull
+	//this method is called, if the try to close was not successful
 	osl::Guard< osl::Mutex > aGuard( m_aAccessMutex );
 	impl_setOwnership( bDeliverOwnership, sal_False );
 
@@ -311,7 +311,7 @@ bool CloseableLifeTimeManager::impl_isDi
 	void CloseableLifeTimeManager
 ::g_close_endTryClose_doClose()
 {
-	//this method is called, if the try to close was successfull
+	//this method is called, if the try to close was successful
 	osl::ResettableGuard< osl::Mutex > aGuard( m_aAccessMutex );
 
 	m_bInTryClose		= sal_False;

Modified: openoffice/trunk/main/chart2/source/tools/XMLRangeHelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/tools/XMLRangeHelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/tools/XMLRangeHelper.cxx (original)
+++ openoffice/trunk/main/chart2/source/tools/XMLRangeHelper.cxx Tue Apr 29 19:05:05 2014
@@ -353,7 +353,7 @@ CellRange getCellRangeFromXMLString( con
                 nStartPos, nEndPos - 1,
                 aResult ))
         {
-            // if an error occured, bail out
+            // if an error occurred, bail out
             return CellRange();
         }
     }

Modified: openoffice/trunk/main/chart2/source/view/axes/VCartesianAxis.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/axes/VCartesianAxis.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/axes/VCartesianAxis.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/axes/VCartesianAxis.cxx Tue Apr 29 19:05:05 2014
@@ -592,7 +592,7 @@ bool VCartesianAxis::createTextShapes(
                      , TickFactory_2D* pTickFactory
                      , sal_Int32 nScreenDistanceBetweenTicks )
 {
-    //returns true if the text shapes have been created succesfully
+    //returns true if the text shapes have been created successfully
     //otherwise false - in this case the AxisLabelProperties have changed
     //and contain new instructions for the next try for text shape creation
 

Modified: openoffice/trunk/main/chart2/source/view/charttypes/Splines.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/charttypes/Splines.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/charttypes/Splines.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/charttypes/Splines.cxx Tue Apr 29 19:05:05 2014
@@ -107,7 +107,7 @@ private:
     */
     void Calculate();
 
-    /** @descr this function corresponds to the algoritm 4.76 in [2] and
+    /** @descr this function corresponds to the algorithm 4.76 in [2] and
         theorem 5.3.7 in [3]
 
         [2] Engeln-Müllges, Gisela: Numerik-Algorithmen: Verfahren, Beispiele, Anwendungen

Modified: openoffice/trunk/main/chart2/source/view/diagram/VDiagram.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/diagram/VDiagram.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/diagram/VDiagram.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/diagram/VDiagram.cxx Tue Apr 29 19:05:05 2014
@@ -379,7 +379,7 @@ void VDiagram::adjustAspectRatio3d( cons
                             lcl_ensureScaleValue(fScaleX);
                         }
                         else
-                            fScaleX = 1.0;//looking from top or bottom hieght is irrelevant
+                            fScaleX = 1.0;//looking from top or bottom height is irrelevant
                     }
                     else
                     {
@@ -424,7 +424,7 @@ void VDiagram::adjustAspectRatio3d( cons
                             lcl_ensureScaleValue(fScaleY);
                         }
                         else
-                            fScaleY = 1.0;//looking from top or bottom hieght is irrelevant
+                            fScaleY = 1.0;//looking from top or bottom height is irrelevant
                         */
                     }
                     else if( fScaleY>0 && fScaleZ>0 )
@@ -437,7 +437,7 @@ void VDiagram::adjustAspectRatio3d( cons
                             lcl_ensureScaleValue(fScaleX);
                         }
                         else
-                            fScaleX = 1.0;//looking from top or bottom hieght is irrelevant
+                            fScaleX = 1.0;//looking from top or bottom height is irrelevant
                     }
                     else
                     {

Modified: openoffice/trunk/main/chart2/source/view/inc/MinimumAndMaximumSupplier.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/inc/MinimumAndMaximumSupplier.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/inc/MinimumAndMaximumSupplier.hxx (original)
+++ openoffice/trunk/main/chart2/source/view/inc/MinimumAndMaximumSupplier.hxx Tue Apr 29 19:05:05 2014
@@ -57,7 +57,7 @@ public:
     virtual bool isExpandNarrowValuesTowardZero( sal_Int32 nDimensionIndex ) = 0;
     virtual bool isSeperateStackingForDifferentSigns( sal_Int32 nDimensionIndex ) = 0;
 
-    //return a constant out of ::com::sun::star::chart::TimeUnit that allows to display the smallest distance between occuring dates
+    //return a constant out of ::com::sun::star::chart::TimeUnit that allows to display the smallest distance between occurring dates
     virtual long calculateTimeResolutionOnXAxis() = 0;
     virtual void setTimeResolutionOnXAxis( long nTimeResolution, const Date& rNullDate ) = 0;
 };

Modified: openoffice/trunk/main/chart2/source/view/main/ChartView.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/main/ChartView.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/main/ChartView.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/main/ChartView.cxx Tue Apr 29 19:05:05 2014
@@ -906,7 +906,7 @@ void SeriesPlotterContainer::setScalesFr
 
 void SeriesPlotterContainer::setNumberFormatsFromAxes()
 {
-    //set numberfarmats to plotter to enable them to display the data labels in the numberfromat of teh axis
+    //set numberfarmats to plotter to enable them to display the data labels in the numberfromat of the axis
 
     ::std::vector< VSeriesPlotter* >::const_iterator       aPlotterIter = m_aSeriesPlotterList.begin();
     const ::std::vector< VSeriesPlotter* >::const_iterator aPlotterEnd  = m_aSeriesPlotterList.end();
@@ -1512,7 +1512,7 @@ awt::Rectangle ChartView::impl_createDia
             pVCooSys->setTransformationSceneToScreen( B3DHomMatrixToHomogenMatrix(
                 createTransformationSceneToScreen( aVDiagram.getCurrentRectangle() ) ));
         }
-        pVCooSys->updatePositions();//todo: logically this belongs to the condition above, but it seems also to be neccessary to give the axes group shapes the right bounding rects for hit test -  probably caused by bug i106183 -> check again if fixed
+        pVCooSys->updatePositions();//todo: logically this belongs to the condition above, but it seems also to be necessary to give the axes group shapes the right bounding rects for hit test -  probably caused by bug i106183 -> check again if fixed
     }
 
     //create axes and grids for the final size
@@ -2530,7 +2530,7 @@ void ChartView::createShapes()
         .getOrCreateChartRootShape( m_xDrawPage ) );
 
     SdrPage* pPage = ChartView::getSdrPage();
-    if(pPage) //it is neccessary to use the implementation here as the uno page does not provide a propertyset
+    if(pPage) //it is necessary to use the implementation here as the uno page does not provide a propertyset
         pPage->SetSize(Size(aPageSize.Width,aPageSize.Height));
     else
     {

Modified: openoffice/trunk/main/chart2/source/view/main/PlottingPositionHelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/chart2/source/view/main/PlottingPositionHelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/chart2/source/view/main/PlottingPositionHelper.cxx (original)
+++ openoffice/trunk/main/chart2/source/view/main/PlottingPositionHelper.cxx Tue Apr 29 19:05:05 2014
@@ -216,7 +216,7 @@ awt::Point PlottingPositionHelper::trans
     //@todo would like to have a cheaper method to do this transformation
     awt::Point aScreenPoint( static_cast<sal_Int32>(rScenePosition3D.PositionX), static_cast<sal_Int32>(rScenePosition3D.PositionY) );
 
-    //transformation from scene to screen (only neccessary for 3D):
+    //transformation from scene to screen (only necessary for 3D):
     if(3==nDimensionCount)
     {
         //create 3D anchor shape

Modified: openoffice/trunk/main/cli_ure/source/climaker/climaker_app.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/cli_ure/source/climaker/climaker_app.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/cli_ure/source/climaker/climaker_app.cxx (original)
+++ openoffice/trunk/main/cli_ure/source/climaker/climaker_app.cxx Tue Apr 29 19:05:05 2014
@@ -718,7 +718,7 @@ SAL_IMPLEMENT_MAIN()
                          osl_getThreadTextEncoding() ) );
         fprintf(
             stderr,
-            "\n> error: .NET exception occured: %s\n> dying abnormally...",
+            "\n> error: .NET exception occurred: %s\n> dying abnormally...",
             msg.getStr() );
         ret = 1;
 	}
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -292,7 +292,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -312,7 +312,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -292,7 +292,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -263,7 +263,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -283,7 +283,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -263,7 +263,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_powerpc64/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -251,7 +251,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -270,7 +270,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -251,7 +251,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -253,7 +253,7 @@ static typelib_TypeClass cpp2uno_call(
     // invoke uno dispatch call
     (*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
     
     // in case an exception occured...
     if (pUnoExc)
     {
         // destruct temporary in/inout params
@@ -272,7 +272,7 @@ static typelib_TypeClass cpp2uno_call(
         // is here for dummy
         return typelib_TypeClass_VOID;
     }
-    else // else no exception occured...
+    else // else no exception occurred...
     {
         // temporary params
         for ( ; nTempIndizes--; )
@@ -253,7 +253,7 @@ static typelib_TypeClass cpp2uno_call(
     (*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
     
-    // in case an exception occured...
+    // in case an exception occurred...
     if (pUnoExc)
     {

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_s390x/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -159,7 +159,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->getUnoI()->pDispatcher)(pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -178,7 +178,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -159,7 +159,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)(pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_sparc/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -194,7 +194,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if ( pUnoExc )
 	{
 		// destruct temporary in/inout params
@@ -213,7 +213,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -194,7 +194,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if ( pUnoExc )
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_linux_x86-64/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -162,7 +162,7 @@ void cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -181,7 +181,7 @@ void cpp2uno_call(
             &aUnoExc, pThis->getBridge()->getUno2Cpp() );
             // has to destruct the any
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -162,7 +162,7 @@ void cpp2uno_call(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_intel/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -142,7 +142,7 @@ static typelib_TypeClass cpp2uno_call(
 		}
 	}
 
-        // now the stack has all of the paramters stored in it ready to be processed
+        // now the stack has all of the parameters stored in it ready to be processed
         // so we are ready to build the uno call stack
 	pCppStack = (char *)ovrflw;
 
@@ -238,7 +238,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)( 
          pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -259,7 +259,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -238,7 +238,7 @@ static typelib_TypeClass cpp2uno_call(
          pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_macosx_powerpc/uno2cpp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -159,7 +159,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->pUnoI->pDispatcher)( pThis->pUnoI, pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -178,7 +178,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -159,7 +159,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->pUnoI->pDispatcher)( pThis->pUnoI, pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_netbsd_intel/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -160,7 +160,7 @@ static typelib_TypeClass cpp2uno_call(
         fprintf( stderr, ">cpp2uno_call pUnoExc %x\n", pUnoExc);
 #endif
 
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -181,7 +181,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -160,7 +160,7 @@ static typelib_TypeClass cpp2uno_call(
 #endif
 
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_os2_intel/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -158,7 +158,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -179,7 +179,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -158,7 +158,7 @@ static typelib_TypeClass cpp2uno_call(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_intel/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -158,7 +158,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->getUnoI()->pDispatcher)(pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -177,7 +177,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -158,7 +158,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)(pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/gcc3_solaris_sparc/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -166,7 +166,7 @@ void cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -185,7 +185,7 @@ void cpp2uno_call(
             &aUnoExc, pThis->getBridge()->getUno2Cpp() );
             // has to destruct the any
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -166,7 +166,7 @@ void cpp2uno_call(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/mingw_intel/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -161,7 +161,7 @@ static inline typelib_TypeClass cpp2uno_
 	(*pThis->getUnoI()->pDispatcher)(
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 
 	// in case an exception occured...
 	if (pUnoExc)
 	{
 		// destruct temporary in/inout params
@@ -186,7 +186,7 @@ static inline typelib_TypeClass cpp2uno_
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		while (nTempIndizes--)
@@ -161,7 +161,7 @@ static inline typelib_TypeClass cpp2uno_
         pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 
-	// in case an exception occured...
+	// in case an exception occurred...
 	if (pUnoExc)
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/msvc_win32_intel/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/cpp2uno.cxx (original)
+++ openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/cpp2uno.cxx Tue Apr 29 19:05:05 2014
@@ -194,7 +194,7 @@ static typelib_TypeClass cpp2uno_call(
 	// invoke uno dispatch call
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
 	// in case an exception occured...
 	if ( pUnoExc )
 	{
 		// destruct temporary in/inout params
@@ -213,7 +213,7 @@ static typelib_TypeClass cpp2uno_call(
 		// is here for dummy
 		return typelib_TypeClass_VOID;
 	}
-	else // else no exception occured...
+	else // else no exception occurred...
 	{
 		// temporary params
 		for ( ; nTempIndizes--; )
@@ -194,7 +194,7 @@ static typelib_TypeClass cpp2uno_call(
 	(*pThis->getUnoI()->pDispatcher)( pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
 	
-	// in case an exception occured...
+	// in case an exception occurred...
 	if ( pUnoExc )
 	{

Modified: openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/except.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/bridges/source/cpp_uno/s5abi_macosx_x86-64/except.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/bridges/source/jni_uno/jni_uno2java.cxx (original)
+++ openoffice/trunk/main/bridges/source/jni_uno/jni_uno2java.cxx Tue Apr 29 19:05:05 2014
@@ -73,7 +73,7 @@ void Bridge::handle_java_exc(
     if (! jo_exc.is())
     {
         throw BridgeRuntimeError(
-            OUSTR("java exception occured, but no java exception available!?") +
+            OUSTR("java exception occurred, but no java exception available!?") +
             jni.get_stack_trace() );
     }
 
@@ -121,7 +121,7 @@ void Bridge::handle_java_exc(
 #if OSL_DEBUG_LEVEL > 1
     OUStringBuffer trace_buf( 128 );
     trace_buf.appendAscii(
-        RTL_CONSTASCII_STRINGPARAM("exception occured uno->java: [") );
+        RTL_CONSTASCII_STRINGPARAM("exception occurred uno->java: [") );
     trace_buf.append( exc_name );
     trace_buf.appendAscii( RTL_CONSTASCII_STRINGPARAM("] ") );
     trace_buf.append(
@@ -408,7 +408,7 @@ void Bridge::call_java(
             }
         } // else: already set integral uno return value
 
         // no exception occured
         *uno_exc = 0;
     }
 #ifdef BROKEN_ALLOCA
@@ -779,7 +779,7 @@ void SAL_CALL UNO_proxy_dispatch(
                                 reinterpret_cast< uno_Any * >( uno_ret ),
                                 0, 0, 0 );
                         }
                         // no exception occured
                         *uno_exc = 0;
                     }
                 }
@@ -408,7 +408,7 @@ void Bridge::call_java(
         } // else: already set integral uno return value
 
-        // no exception occured
+        // no exception occurred
         *uno_exc = 0;
     }
@@ -779,7 +779,7 @@ void SAL_CALL UNO_proxy_dispatch(
                                 0, 0, 0 );
                         }
-                        // no exception occured
+                        // no exception occurred
                         *uno_exc = 0;
                     }

Modified: openoffice/trunk/main/canvas/inc/canvas/base/bitmapcanvasbase.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/canvas/inc/canvas/base/bitmapcanvasbase.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================